@@ -1,7 +1,7 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
     Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
@@ -24,9 +24,9 @@
 
 #include "contactactionssettings.h"
 
-#include <kaboutdata.h>
-#include <kconfigdialogmanager.h>
-#include <kpluginfactory.h>
+#include <KAboutData>
+#include <KConfigDialogManager>
+#include <KPluginFactory>
 #include <KLocalizedString>
 
 Q_DECLARE_METATYPE(ContactActionsSettings::EnumDialPhoneNumberAction)
@@ -54,22 +54,30 @@ KCMAkonadiContactActions::KCMAkonadiContactActions(QWidget *parent, const QVaria
     ui.DialPhoneNumberAction->addItem(i18n("Ekiga"), ContactActionsSettings::UseEkiga);
     ui.DialPhoneNumberAction->addItem(i18n("SflPhone"), ContactActionsSettings::UseSflPhone);
     ui.DialPhoneNumberAction->addItem(i18n("External Application"), ContactActionsSettings::UseExternalPhoneApplication);
-
-    connect(ui.DialPhoneNumberAction, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotDialPhoneNumberActionChanged);
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    connect(ui.DialPhoneNumberAction, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotDialPhoneNumberActionChanged);
+#else
+    connect(ui.DialPhoneNumberAction, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotDialPhoneNumberActionChanged);
+#endif
     ui.SendSmsAction->addItem(i18n("System Default"), ContactActionsSettings::UseSystemDefaultSms);
     ui.SendSmsAction->addItem(i18n("Skype"), ContactActionsSettings::UseSkypeSms);
     ui.SendSmsAction->addItem(i18n("SflPhone"), ContactActionsSettings::UseSflPhoneSms);
     ui.SendSmsAction->addItem(i18n("External Application"), ContactActionsSettings::UseExternalSmsApplication);
-    connect(ui.SendSmsAction, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotSmsPhoneNumberActionChanged);
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    connect(ui.SendSmsAction, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotSmsPhoneNumberActionChanged);
+#else
+    connect(ui.SendSmsAction, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotSmsPhoneNumberActionChanged);
+#endif
     ui.ShowAddressAction->addItem(i18n("Web Browser"), ContactActionsSettings::UseBrowser);
     ui.ShowAddressAction->addItem(i18n("External Application"), ContactActionsSettings::UseExternalAddressApplication);
     ui.ShowAddressAction->addItem(i18n("Google map"), ContactActionsSettings::UseGooglemap);
     ui.ShowAddressAction->addItem(i18n("Map quest"), ContactActionsSettings::UseMapquest);
     ui.ShowAddressAction->addItem(i18n("OpenStreetMap"), ContactActionsSettings::UseOpenStreetMap);
-
-    connect(ui.ShowAddressAction, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotShowAddressActionChanged);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    connect(ui.ShowAddressAction, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotShowAddressActionChanged);
+#else
+    connect(ui.ShowAddressAction, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotShowAddressActionChanged);
+#endif
 
     load();
 }
