@@ -68,7 +68,7 @@ public:
     /**
      * Destroys the contact group viewer.
      */
-    ~ContactGroupViewer();
+    ~ContactGroupViewer() override;
 
     /**
      * Returns the contact group that is currently displayed.
@@ -116,9 +116,6 @@ private:
     //@cond PRIVATE
     class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void _k_expandResult(KJob *))
-    Q_PRIVATE_SLOT(d, void slotParentCollectionFetched(KJob *))
     //@endcond
 };
 }
